<?php
if (!defined('SIMPLE_TEST')) {
    define('SIMPLE_TEST', '../../lib/simpletest/');
}
require_once(SIMPLE_TEST . 'unit_tester.php');
require_once(SIMPLE_TEST . 'reporter.php');
require_once "../../owllib/OWLLib.php";
require_once "$OWLLIB_ROOT/reader/OWLReader.php";
require_once "$OWLLIB_ROOT/writer/OWLWriter.php";
require_once "$OWLLIB_ROOT/memory/OWLMemoryOntology.php";


	$test_writer = false;
	if(array_key_exists("writer", $_GET))
		$test_writer = true;


	//===========================================================================
	// Unit test class
	class BaseTest extends UnitTestCase {
        
		//-------------------------------------------------------------------------
		/**
		 * Constructor
		 */        
  	function BaseTest($test_writer) {
    	$this->UnitTestCase();
    	
			$reader = new OWLReader();
			$this->ontology = new OWLMemoryOntology();
			$reader->readFromFile("../ontologies/base.owl", $this->ontology);

    	if($test_writer){
				$tmpfname = tempnam("/tmp", "owllib");
				//$tmpfname = "/tmp/test.xml";
				$writer = new OWLWriter();
				$writer->writeToFile($tmpfname, $this->ontology);
				$this->ontology = new OWLMemoryOntology();
				$reader = new OWLReader();
				$reader->readFromFile($tmpfname, $this->ontology);
				unlink($tmpfname);	   	
    	}
    }


		//-------------------------------------------------------------------------
		/**
		 * ontology should exists
		 */
  	function testOntology() {

	   	$this->assertNotNull($this->ontology);
	  }


		//-------------------------------------------------------------------------
		/**
		 * check namespace
		 */
  	function testNamespace() {

	   	$this->assertTrue($this->ontology->getNamespace() == "http://www.example.org/ontology#");
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check get class
		 */
  	function testgetClassByID() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#PlanetarySystem");
   		$this->assertIsA($class, "OWLClass");
   		$this->assertTrue($class->getID() == "http://www.example.org/ontology#PlanetarySystem");
			
	  }


		//-------------------------------------------------------------------------
		/**
		 * There should 3 be top level classes
		 */
  	function testRootSubclasses() {

			$class = $this->ontology->getClass("http://www.w3.org/2002/07/owl#Thing");
			$classes = $class->getSubclasses();
	   	$this->assertTrue(count($classes) > 0);
			
	  }


		//-------------------------------------------------------------------------
		/**
		 * http://www.w3.org/2002/07/owl#Thing doesn't have parent
		 */
  	function testRootSuperclasses() {

			$class = $this->ontology->getClass("http://www.w3.org/2002/07/owl#Thing");
			$classes = $class->getSuperclasses();
	   	$this->assertEqual(count($classes), 0);
			
	  }


		//-------------------------------------------------------------------------
		/**
		 * Class Person is super class of Astonaut
		 */
  	function testSubClasses() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");
			$classes = $class->getSubclasses();
	   	$this->assertTrue(count($classes) > 0);
			
			$found = false;
	   	foreach($classes as $class){
	   		
	   		if($class->getID() == "http://www.example.org/ontology#Astronaut")
	   			$found = true;
	   	}
	   	
	   	$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Class Astronaut is subclassof Person
		 */
  	function testSuperClasses() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Astronaut");
			$classes = $class->getSuperclasses();
	   	$this->assertEqual(count($classes), 1);
			
	   	foreach($classes as $class){
	   		
	   		$this->assertTrue($class->getID() == "http://www.example.org/ontology#Person");
	   	}
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check function getSuperClasses 
		 * Should return #Person class
		 */
  	function test31() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Astronaut");
			$superclasses = $class->getSuperClasses(); 
	   	$this->assertEqual(count($superclasses), 1);

			$parent = $superclasses[0];			
   		$this->assertTrue($parent->getID() == "http://www.example.org/ontology#Person");
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check function getSuperClasses 
		 * Should return http://www.w3.org/2002/07/owl#Thing class
		 */
  	function test32() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");
			$superclasses = $class->getSuperClasses(); 
	   	$this->assertEqual(count($superclasses), 1);

			$parent = $superclasses[0];			
   		$this->assertTrue($parent->getID() == "http://www.w3.org/2002/07/owl#Thing");
	  }


		//-------------------------------------------------------------------------
		/**
		 * Get http://www.w3.org/2002/07/owl#Thing class 
		 * Should return http://www.w3.org/2002/07/owl#Thing class
		 */
  	function testgetOWLThing() {

			$class = $this->ontology->getClass("http://www.w3.org/2002/07/owl#Thing");
   		$this->assertIsA($class, "OWLClass");
   		$this->assertTrue($class->getID() == "http://www.w3.org/2002/07/owl#Thing");
	  }


		//-------------------------------------------------------------------------
		/**
		 * Test wrong class id 
		 */
  	function testNoClass() {

			$class = $this->ontology->getClass("NoClass");
   		$this->assertNull($class);
	  }


		//-------------------------------------------------------------------------
		/**
		 * class http://www.w3.org/2002/07/owl#Thing have 3 children
		 */
  	function testThingChildren() {

			$class = $this->ontology->getClass("http://www.w3.org/2002/07/owl#Thing");
			$classes = $class->getSubclasses();
	   	$this->assertTrue(count($classes) > 0);
			
	  }


		//-------------------------------------------------------------------------
		/**
		 * Ther should be property
		 */
  	function testProperties() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");
			$properties = $class->getProperties(false);
	   	$this->assertNotNull($properties);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Ther should be property
		 */
  	function testClassProperty() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Planet");
			$properties = $class->getProperties(false);
			
			$found = false;
			foreach($properties as $property){
				if($property->getID() == "http://www.example.org/ontology#distance"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Person is superclass of Astronaut
		 */
  	function testPerson2Astronaut() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Astronaut");
			$superclasses = $class->getSuperclasses();
			
			$found = false;
			foreach($superclasses as $super){
				if($super->getID() == "http://www.example.org/ontology#Person"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * There should be property
		 */
  	function testPersonBornOn() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");
			$properties = $class->getProperties(true);
			
			$found = false;
			foreach($properties as $property){
				if($property->getID() == "http://www.example.org/ontology#born_on"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * There should be property
		 */
  	function testgetPropertiesfromParent() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Astronaut");
			$properties = $class->getProperties(true);
			
			$found = false;
			foreach($properties as $property){
				if($property->getID() == "http://www.example.org/ontology#born_on"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * There shouldn't be property
		 */
  	function testNoSuperClassProperty() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Astronaut");
			$properties = $class->getProperties(false);
			
			$found = false;
			foreach($properties as $property){
				if($property->getID() == "http://www.example.org/ontology#born_on"){
					$found = true;
					break;
				}
			}
			
			$this->assertFalse($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Ther should be property
		 */
  	function testDatatypeProperty() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Planet");
			$properties = $class->getProperties(false);
			
			$found = null;
			foreach($properties as $property){
				if($property->getID() == "http://www.example.org/ontology#distance"){
					$found = $property;
					break;
				}
			}
			
			$this->assertTrue($found->isDatatype());
	  }


		//-------------------------------------------------------------------------
		/**
		 * Ther should be property
		 */
  	function testNotDatatypeProperty() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");
			$properties = $class->getProperties(false);
			
			$found = null;
			foreach($properties as $property){
				if($property->getID() == "http://www.example.org/ontology#born_on"){
					$found = $property;
					break;
				}
			}
			
			$this->assertFalse($found->isDatatype());
	  }


		//-------------------------------------------------------------------------
		/**
		 * Ther should be property
		 */
  	function testPropertyDomain() {

			$property = $this->ontology->getProperty("http://www.example.org/ontology#distance");
			$classes = $property->getDomain();

			$found = false;
			foreach($classes as $class){
				if($class->getID() == "http://www.example.org/ontology#Planet"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	   	
	  }


		//-------------------------------------------------------------------------
		/**
		 * Test property range
		 */
  	function testPropertyRange() {
			$property = $this->ontology->getProperty("http://www.example.org/ontology#is_in");
			$classes = $property->getRange();

			$found = false;
			foreach($classes as $class){
				if($class->getID() == "http://www.example.org/ontology#PlanetarySystem"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * check instances
		 */
  	function testClassInstances() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");
			$instances = $class->getInstances();
	   	$this->assertNotNull($instances);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testClassInstance() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Planet");
			$instances = $class->getInstances();
	   	$this->assertNotNull($instances);

			$found = false;
			foreach($instances as $instance){
				if($instance->getID() == "http://www.example.org/ontology#Venus"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testInstance() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#Mars");
	   	$this->assertIsA($instance, "OWLInstance");
	   	$this->assertTrue($instance->getID() == "http://www.example.org/ontology#Mars");
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testInstanceClass() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#AnnLenox");
	   	$this->assertIsA($instance, "OWLInstance");
	   	$class = $instance->getClass();
	   	$this->assertTrue($class->getID() == "http://www.example.org/ontology#Astronaut");
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testInstanceValuesNotNull() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#AnnLenox");
	   	$values = $instance->getPropertyValues("http://www.example.org/ontology#born_on");
	   	$this->assertNotNull($values);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testInstanceValues() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#Mars");
	   	$values = $instance->getPropertyValues("http://www.example.org/ontology#is_in");

			$found = false;
			foreach($values as $value){
				if($value->getID() == "http://www.example.org/ontology#SolarSystem"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * test inverse of
		 */
  	function testInverseOf() {
  		
			$instance = $this->ontology->getInstance("http://www.example.org/ontology#SolarSystem");
	   	$values = $instance->getPropertyValues("http://www.example.org/ontology#has_planets");

			$found = false;
			foreach($values as $value){
				if($value->getID() == "http://www.example.org/ontology#Mars"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testInstanceParentValues() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#AnnLenox");
	   	$values = $instance->getPropertyValues("http://www.example.org/ontology#born_on");

			$found = false;
			foreach($values as $value){
				if($value->getID() == "http://www.example.org/ontology#Earth"){
					$found = true;
					break;
				}
			}
			
			$this->assertTrue($found);
	  }


		//-------------------------------------------------------------------------
		/**
		 * Check instance
		 */
  	function testNoInstanceValues() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#Mars");
	   	$values = $instance->getPropertyValues("http://www.example.org/ontology#distance");

			$this->assertEqual(count($values), 0);
	  }


		//-------------------------------------------------------------------------
		/**
		 * check class label
		 */
  	function testClassLabel() {

			$class = $this->ontology->getClass("http://www.example.org/ontology#Person");

	   	$this->assertTrue($class->getLabel("pl") == "Osoba");
	  }


		//-------------------------------------------------------------------------
		/**
		 * check property label
		 */
  	function testPropertyLabel() {

			$property = $this->ontology->getProperty("http://www.example.org/ontology#is_in");

	   	$this->assertTrue($property->getLabel("en") == "is in");
	  }


		//-------------------------------------------------------------------------
		/**
		 * check instance label
		 */
  	function testInstanceLabel() {

			$instance = $this->ontology->getInstance("http://www.example.org/ontology#AnnLenox");

	   	$this->assertTrue($instance->getLabel("en") == "Ann Lenox");
	  }


		//-------------------------------------------------------------------------
		/**
		 * check no label
		 */
  	function testNoLabel() {

			$property = $this->ontology->getClass("http://www.example.org/ontology#PlanetarySystem");

	   	$this->assertTrue($property->getLabel("no-lang") == "http://www.example.org/ontology#PlanetarySystem");
	  }


		//-------------------------------------------------------------------------
		/**
		 * check owl:Thing label
		 */
  	function testThingLabel() {

			$property = $this->ontology->getClass("http://www.w3.org/2002/07/owl#Thing");

	   	$this->assertTrue($property->getLabel("en") == "Thing");
	  }


		//-------------------------------------------------------------------------
		// Private members
		var		$ontology;

  }

	//===========================================================================
	// Start unit test
  $test = new BaseTest($test_writer);
  $test->run(new HtmlReporter());    
    
?>
 
<p>
<a href="/tests/index.php">Test list</a>
</p>
 