<?php

if (!defined('SIMPLE_TEST')) {
    define('SIMPLE_TEST', '../../lib/simpletest/');
}
require_once(SIMPLE_TEST . 'unit_tester.php');
require_once(SIMPLE_TEST . 'reporter.php');
require_once "../../owllib/util/OWLExpression.php";


	//===========================================================================
	// Unit test class
	class ExpressionTest extends UnitTestCase {

		//-------------------------------------------------------------------------
		/**
		 * Constructor
		 */
  	function ExpressionTest() {
    	$this->UnitTestCase();

    }


		//-------------------------------------------------------------------------
		/**
		 * Test simple expression
		 */
  	function testSimpleVariables() {

	   	$exp = new OWLExpression("a=15");
	   	$variables = $exp->getVariables();
	   	$this->assertEqual(count($variables), 1);
	   	$this->assertTrue(in_array("a", $variables));

	  }


		//-------------------------------------------------------------------------
		/**
		 * Test complex expression
		 */
  	function testComplexVariables() {

	   	$exp = new OWLExpression("a=15 AND bec='abc' OR (test=25 AND was='ala ola')");
	   	$variables = $exp->getVariables();
	   	$this->assertEqual(count($variables), 4);
	   	$this->assertTrue(in_array("a", $variables));
	   	$this->assertTrue(in_array("bec", $variables));
	   	$this->assertTrue(in_array("test", $variables));
	   	$this->assertTrue(in_array("was", $variables));

	  }


		//-------------------------------------------------------------------------
		/**
		 * Test simple expression
		 */
  	function testSimple() {

	   	$exp = new OWLExpression("a=15");
	   	$values['a'] = 15;
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 25;
	   	$this->assertFalse($exp->evaluate($values));

	   	$exp = new OWLExpression("15=a");
	   	$values['a'] = 15;
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 25;
	   	$this->assertFalse($exp->evaluate($values));
	  }


		//-------------------------------------------------------------------------
		/**
		 * Test simple expression
		 */
  	function testString() {

	   	$exp = new OWLExpression("a='ala'");
	   	$values['a'] = 'ala';
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 'ola';
	   	$this->assertFalse($exp->evaluate($values));

	   	$exp = new OWLExpression("'ala'=a");
	   	$values['a'] = 'ala';
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 'ola';
	   	$this->assertFalse($exp->evaluate($values));
	  }


		//-------------------------------------------------------------------------
		/**
		 * Test simple expression
		 */
  	function testMixed() {

	   	$exp = new OWLExpression("a='ala' AND c=15");
	   	$values['a'] = 'ala';
	   	$values['c'] = 15;
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 'ola';
	   	$values['c'] = 15;
	   	$this->assertFalse($exp->evaluate($values));

	   	$values['a'] = 'ala';
	   	$values['c'] = 23;
	   	$this->assertFalse($exp->evaluate($values));

	  }


		//-------------------------------------------------------------------------
		/**
		 * Test complex expression
		 */
  	function testSpace() {

	   	$exp = new OWLExpression("a='ala ola'");
	   	$values['a'] = 'ala ola';
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 'ala';
	   	$this->assertFalse($exp->evaluate($values));

	   	$values['a'] = 'ola';
	   	$this->assertFalse($exp->evaluate($values));
	  }


		//-------------------------------------------------------------------------
		/**
		 * Test complex expression
		 */
  	function testArrayValue() {

	   	$exp = new OWLExpression("a=15");
	   	$values['a'] = array(15, 23);
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = array(44, 23);
	   	$this->assertFalse($exp->evaluate($values));
	  }


		//-------------------------------------------------------------------------
		/**
		 * Test complex expression
		 */
  	function testComplex() {

	   	$exp = new OWLExpression("(a=15 AND bec='abc') OR (test=25 AND was='ala ola')");
	   	$values['a'] = 15;
	   	$values['bec'] = 'abc';
	   	$values['test'] = 25;
	   	$values['was'] = 'ala ola';
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 15;
	   	$values['bec'] = 'abc';
	   	$values['test'] = 25;
	   	$values['was'] = 'ola';
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 23;
	   	$values['bec'] = 'abc';
	   	$values['test'] = 25;
	   	$values['was'] = 'ala ola';
	   	$this->assertTrue($exp->evaluate($values));

	   	$values['a'] = 23;
	   	$values['bec'] = 'abc';
	   	$values['test'] = 25;
	   	$values['was'] = 'ala';
	   	$this->assertFalse($exp->evaluate($values));

	  }


		//-------------------------------------------------------------------------
		// Private members

  }

	//===========================================================================
	// Start unit test
  $test = new ExpressionTest();
  $test->run(new HtmlReporter());

?>

<p>
<a href="/tests/index.php">Test list</a>
</p>
